pub struct LsbRelease { /* private fields */ }Expand description
Release information typically gathered from the environment or from
/etc/lsb-release.
Implementations
Sourceimpl LsbRelease
impl LsbRelease
Sourcepub fn get<K: AsRef<str>>(&self, k: K) -> Option<&str>
pub fn get<K: AsRef<str>>(&self, k: K) -> Option<&str>
Gets arbitrary release information, or none if unavailable.
Sourcepub fn release_channel(&self) -> Option<ReleaseChannel<'_>>
pub fn release_channel(&self) -> Option<ReleaseChannel<'_>>
Gets the type of release channel this release information corresponds to, or none if this information was not indicated.